Patch pyproject reading
========================

.. automodule:: drain_swamp.monkey.patch_pyproject_reading
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: setuptools_scm is too strict monkey patch it
